@@ -1,7 +1,7 @@
 import os, sys, subprocess
 
 from .user_config import get_user_config
-from .poetry_setup import setup_poetry, lock_poetry_dependencies_on_docker
+from .poetry_setup import setup_poetry
 from .pytest_setup import setup_pytest
 from .django_project_setup import create_django_project
 from .docker_build import docker_build_and_start, docker_stop
@@ -51,9 +51,6 @@ def main():
     print("\n  ■ Initializing Docker container\n")
     docker_build_and_start()
 
-    print("\n  ■ Locking poetry dependencies\n")
-    lock_poetry_dependencies_on_docker(config)
-
     print("\n  ■ Creating Django project\n")
     create_django_project(config)
 
